/*
 * Copyright (C) 2004  Stefan Kleine Stegemann
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef _H_PDFPRINTVIEW
#define _H_PDFPRINTVIEW

#import <AppKit/NSView.h>
#import <PDFKit/PDFDocument.h>

/**
 * A view that could be used for printing PDF documents.
 * The view's implementation uses PDFKit to produce
 * postscript code that is optimized for printing.
 * 
 * Note that you cannot use this view to display PDF
 * documents on the screen.
 */
@interface PDFPrintView : NSView
{
   PDFDocument*  document;
   void*         psDevice;
}

/** Initialize the receiver for printing the content's of
 *  a PDF document. The document is retained by the receiver.
 *  This view does not need an initial frame  because it is
 *  optimized for printing and thus will detect it's 'size' when
 *  printed.  */
- (id) initWithDocument: (PDFDocument*)aDocument;

@end

#endif
